/*
 * Frame.cpp
 *
 *  Created on: Jul 28, 2014
 *      Author: coert
 */

#include "Frame.h"

namespace nl_uu_science_gmt
{

void Frame::write(cv::FileStorage &fs) const
{
	assert(fs.isOpened());

	fs << "{";
	fs << "id" << (int) s_id;
	fs << "image_filename" << s_image_filename;
	if(s_rotation != nullptr)
		fs << "rotation" << *s_rotation;
	if(s_translation != nullptr)
		fs << "translation" << *s_translation;
	fs << "skeletons_amount" << (int) s_skeletons.size();
	if(!s_skeletons.empty())
	{
		fs << "skeletons";
		fs << "{";
		for(auto skeleton : s_skeletons)
		{
			std::stringstream skeleton_name;
			skeleton_name << "skeleton_" << skeleton->getId();
			fs << skeleton_name.str() << *skeleton;
		}
		fs << "}";
	}
	fs << "}";
}

void Frame::read(const cv::FileNode &fn)
{
	assert(fn.type() == cv::FileNode::MAP);

	int id = 0;
	fn["id"] >> id;
	s_id = id;
	fn["image_filename"] >> s_image_filename;
	cv::Mat rotation;
	fn["rotation"] >> rotation;
	cv::Mat translation;
	fn["translation"] >> translation;
	for (cv::FileNodeIterator n = fn["skeletons"].begin(); n != fn["skeletons"].end();)
	{
		Skeleton skeleton;
		n >> skeleton;
		addSkeleton(skeleton);
	}
}

void Frame::getImage(cv::Mat &image, bool flip)
{
	if(s_video->getVideoCapture() != nullptr)
	{
		s_video->getVideoCapture()->set(CV_CAP_PROP_POS_FRAMES, s_id);
		*s_video->getVideoCapture() >> image;
	}
	else
	{
		std::stringstream image_file;
		image_file << *s_video->getVideoPath() << s_video->getImagePath() << s_image_filename;
		image = cv::imread(image_file.str());
	}
	if(flip) cv::flip(image, image, 1);
}

void Frame::addSkeleton(const Skeleton &skeleton)
{
	s_skeletons.push_back(std::make_shared<Skeleton>(skeleton));
}

}
/* namespace nl_uu_science_gmt */
