/*
 * Frame.h
 *
 *  Created on: Jul 28, 2014
 *      Author: coert
 */

#ifndef FRAME_H_
#define FRAME_H_

#include <memory>
#include <opencv2/opencv.hpp>

#include "IO.h"
#include "Types.h"
#include "Video.h"
#include "Skeleton.h"

namespace nl_uu_science_gmt
{

class Frame
{
	uint s_id;
	std::string s_image_filename;
	Video* s_video = nullptr;

	Skeletons s_skeletons;

	MatPtr s_rotation = nullptr;
	MatPtr s_translation = nullptr;

public:
	void getImage(cv::Mat &, bool = false);
	void addSkeleton(const Skeleton &);

	void write(cv::FileStorage &) const;
	void read(const cv::FileNode &);

	uint getId() const
	{
		return s_id;
	}

	void setId(uint id)
	{
		s_id = id;
	}

	const Video* getVideo() const
	{
		return s_video;
	}

	void setVideo(Video* video)
	{
		s_video = video;
	}

	const Skeletons& getSkeletons() const
	{
		return s_skeletons;
	}

	const MatPtr& getRotation() const
	{
		return s_rotation;
	}

	void setRotation(const MatPtr& rotation = nullptr)
	{
		s_rotation = rotation;
	}

	const MatPtr& getTranslation() const
	{
		return s_translation;
	}

	void setTranslation(const MatPtr& translation = nullptr)
	{
		s_translation = translation;
	}

	const std::string& getImageFilename() const
	{
		return s_image_filename;
	}

	void setImageFilename(const std::string& imageFilename)
	{
		s_image_filename = imageFilename;
	}
};

} /* namespace nl_uu_science_gmt */

#endif /* FRAME_H_ */
