/*
 * ShakeFive.cpp
 *
 *  Created on: Jul 28, 2014
 *      Author: coert
 */

#include "ShakeFive.h"

using namespace nl_uu_science_gmt;

namespace nl_uu_science_gmt
{

ShakeFive::ShakeFive(const std::string &metadata_filename) :
		c_metadata_filename(metadata_filename)
{
}

ShakeFive::~ShakeFive()
{
}

std::vector<std::string> ShakeFive::explode(const std::string &sep, std::string input)
{
	std::vector<std::string> output;
	size_t found = input.find(sep);

	while (found != std::string::npos)
	{
		output.push_back(input.substr(0, found));
		input = input.substr(found + sep.length());
		found = input.find(sep);
	}
	if (input.length() > 0) output.push_back(input);

	return output;
}

std::string ShakeFive::implode(const std::string &glue, const std::vector<std::string> &parts)
{
	std::stringstream output;
	auto piece = parts.begin();
	for (; piece != parts.end(); ++piece)
		output << *piece << glue;

	return output.str().substr(0, output.str().size() - glue.size());
}

void ShakeFive::help(const std::string &bin_name, const std::string &example)
{
	std::cout << "Usage: " << bin_name << " <path to xml-file> [<path to xml-file>] ..." << std::endl;
	std::cout << "Trying to play: " << example << std::endl << std::endl;

	std::cout << "Controls: <ESC> - quit" << std::endl;
	std::cout << "          p     - pause playback" << std::endl;
	std::cout << "          n     - next video (if applicable)" << std::endl << std::endl;
}

int ShakeFive::play()
{
	cv::FileStorage fs(c_metadata_filename, cv::FileStorage::READ);
	auto path_parts = explode(PATH_SEP, c_metadata_filename);
	path_parts.erase(path_parts.end() - 1, path_parts.end());
	auto pre_sep = "";
	if(c_metadata_filename.substr(0, 1) == PATH_SEP) pre_sep = PATH_SEP;
	std::string video_path = pre_sep + implode(PATH_SEP, path_parts) + PATH_SEP;

	Video video;
	video.setVideoPath(std::make_shared<std::string>(video_path));
	fs["video"] >> video;

	return video.play();
}

} /* namespace nl_uu_science_gmt */

int main(int argc, char** argv)
{
	std::vector<std::string> files;

	std::string basepath;
	if (argc > 1)
	{
		for(int i = 1; i < argc; ++i)
			files.push_back(argv[i]);
	}
	else
	{
		basepath = "data/";
		basepath += (basepath.substr(basepath.size() - 1, 1) != PATH_SEP ? PATH_SEP : "");
		files.push_back(basepath + "0009.xml");
	}

	ShakeFive::help(argv[0], files[0]);

	for (size_t i = 0; i < files.size(); ++i)
	{
		std::cout << (i + 1) << PATH_SEP << files.size() << ": " << files[i] << std::endl;

		ShakeFive sf(files[i]);
		int key = sf.play();

		if (key == 27) break;
	}

	return EXIT_SUCCESS;
}
