/*
 * types.h
 *
 *  Created on: Jul 28, 2014
 *      Author: coert
 */

#ifndef TYPES_H_
#define TYPES_H_

#include <opencv2/opencv.hpp>

namespace nl_uu_science_gmt
{

typedef std::shared_ptr<cv::Mat> MatPtr;

class Video;
typedef std::shared_ptr<Video> SVidPtr;
typedef std::vector<SVidPtr> Videos;

class Frame;
typedef std::shared_ptr<Frame> SFramePtr;
typedef std::vector<SFramePtr> Frames;

class Skeleton;
typedef std::shared_ptr<Skeleton> SSkelPtr;
typedef std::vector<SSkelPtr> Skeletons;

typedef enum _NUI_SKELETON_POSITION_INDEX
{
	SKELETON_POSITION_HIP_CENTER = 0,
	SKELETON_POSITION_SPINE = (SKELETON_POSITION_HIP_CENTER + 1),
	SKELETON_POSITION_SHOULDER_CENTER = (SKELETON_POSITION_SPINE + 1),
	SKELETON_POSITION_HEAD = (SKELETON_POSITION_SHOULDER_CENTER + 1),
	SKELETON_POSITION_SHOULDER_LEFT = (SKELETON_POSITION_HEAD + 1),
	SKELETON_POSITION_ELBOW_LEFT = (SKELETON_POSITION_SHOULDER_LEFT + 1),
	SKELETON_POSITION_WRIST_LEFT = (SKELETON_POSITION_ELBOW_LEFT + 1),
	SKELETON_POSITION_HAND_LEFT = (SKELETON_POSITION_WRIST_LEFT + 1),
	SKELETON_POSITION_SHOULDER_RIGHT = (SKELETON_POSITION_HAND_LEFT + 1),
	SKELETON_POSITION_ELBOW_RIGHT = (SKELETON_POSITION_SHOULDER_RIGHT + 1),
	SKELETON_POSITION_WRIST_RIGHT = (SKELETON_POSITION_ELBOW_RIGHT + 1),
	SKELETON_POSITION_HAND_RIGHT = (SKELETON_POSITION_WRIST_RIGHT + 1),
	SKELETON_POSITION_HIP_LEFT = (SKELETON_POSITION_HAND_RIGHT + 1),
	SKELETON_POSITION_KNEE_LEFT = (SKELETON_POSITION_HIP_LEFT + 1),
	SKELETON_POSITION_ANKLE_LEFT = (SKELETON_POSITION_KNEE_LEFT + 1),
	SKELETON_POSITION_FOOT_LEFT = (SKELETON_POSITION_ANKLE_LEFT + 1),
	SKELETON_POSITION_HIP_RIGHT = (SKELETON_POSITION_FOOT_LEFT + 1),
	SKELETON_POSITION_KNEE_RIGHT = (SKELETON_POSITION_HIP_RIGHT + 1),
	SKELETON_POSITION_ANKLE_RIGHT = (SKELETON_POSITION_KNEE_RIGHT + 1),
	SKELETON_POSITION_FOOT_RIGHT = (SKELETON_POSITION_ANKLE_RIGHT + 1),
	SKELETON_POSITION_COUNT = (SKELETON_POSITION_FOOT_RIGHT + 1)
} NUI_SKELETON_POSITION_INDEX;

typedef std::map<NUI_SKELETON_POSITION_INDEX, cv::Point2i> JointPoint2iMap;
typedef std::map<NUI_SKELETON_POSITION_INDEX, cv::Point3d> JointPoint3dMap;
typedef std::map<NUI_SKELETON_POSITION_INDEX, std::string> JointNameMap;

typedef enum _ACTION_CLASSES_INDEX
{
	AC_STANDING = 1,
	AC_APPROACHING = 2,
	AC_HANDSHAKING = 3,
	AC_HIGHFIVE = 4,
	AC_LEAVING = 5,
	AC_END = 6,
	AC_NA = -1
} ACTION_CLASSES_INDEX;

typedef std::map<ACTION_CLASSES_INDEX, std::string> ActionNameMap;

}

#endif /* TYPES_H_ */
