/*
 * Video.h
 *
 *  Created on: Jul 28, 2014
 *      Author: coert
 */

#ifndef VIDEO_H_
#define VIDEO_H_

#include <memory>
#include <opencv2/opencv.hpp>

#include "IO.h"
#include "Types.h"
#include "Frame.h"

namespace nl_uu_science_gmt
{

class Video
{
	uint s_id = 0;
	std::shared_ptr<std::string> s_video_path = nullptr;
	std::string s_video_metadata_filename = "";
	std::string s_video_filename = "";
	std::string s_image_path  = "";

	Frames s_frames;
	std::shared_ptr<cv::VideoCapture> s_video_capture = nullptr;
	MatPtr s_camera_matrix = nullptr;
	MatPtr s_dist_coeff = nullptr;
	cv::Size s_size;

	bool s_paused = false;
	bool s_stop = false;
	bool s_next = false;
	void keyboard(const int);

public:
	void addFrame(Frame &);

	void write(cv::FileStorage &) const;
	void read(const cv::FileNode &);

	void createVideoCapture(const std::string &);

	int play();

	const Frames& getFrames() const
	{
		return s_frames;
	}

	void setFrames(const Frames& frames)
	{
		s_frames = frames;
	}

	const std::shared_ptr<cv::VideoCapture>& getVideoCapture() const
	{
		return s_video_capture;
	}

	const MatPtr& getCameraMatrix() const
	{
		return s_camera_matrix;
	}

	void setCameraMatrix(const MatPtr& cameraMatrix)
	{
		s_camera_matrix = cameraMatrix;
	}

	const MatPtr& getDistCoeff() const
	{
		return s_dist_coeff;
	}

	void setDistCoeff(const MatPtr& distCoeff)
	{
		s_dist_coeff = distCoeff;
	}

	uint getId() const
	{
		return s_id;
	}

	void setId(uint id)
	{
		s_id = id;
	}

	const std::string& getVideoFilename() const
	{
		return s_video_filename;
	}

	void setVideoFilename(const std::string& videoFilename)
	{
		s_video_filename = videoFilename;
	}

	const std::string& getVideoMetadataFilename() const
	{
		return s_video_metadata_filename;
	}

	void setVideoMetadataFilename(const std::string& videoMetadataFilename)
	{
		s_video_metadata_filename = videoMetadataFilename;
	}

	const std::shared_ptr<std::string>& getVideoPath() const
	{
		return s_video_path;
	}

	void setVideoPath(const std::shared_ptr<std::string>& videoPath)
	{
		s_video_path = videoPath;
	}

	const cv::Size& getSize() const
	{
		return s_size;
	}

	void setSize(const cv::Size& size)
	{
		s_size = size;
	}

	const std::string& getImagePath() const
	{
		return s_image_path;
	}

	void setImagePath(const std::string& imagePath = "")
	{
		s_image_path = imagePath;
	}
};

} /* namespace nl_uu_science_gmt */

#endif /* VIDEO_H_ */
